pub struct SocketRuntimeProvider {
pub label: String,
pub socket: PathBuf,
}Expand description
RuntimeProvider backed by a Unix socket path.
Available iff the tilde-expanded path exists on disk.
Fields
label: Stringsocket: PathBufTrait Implementations
Sourceimpl RuntimeProvider for SocketRuntimeProvider
impl RuntimeProvider for SocketRuntimeProvider
Sourcefn name(&self) -> &str
fn name(&self) -> &str
Short, stable identifier used in config keys and log output
(e.g.
"orbstack", "docker-desktop", "colima", "podman",
"docker", "custom").Sourcefn available(&self) -> bool
fn available(&self) -> bool
True when the runtime can be used right now (socket exists, etc.).
Sourcefn docker_host(&self) -> String
fn docker_host(&self) -> String
The value for the
DOCKER_HOST env var
(e.g. "unix:///…" or "tcp://localhost:2375").Auto Trait Implementations
impl Freeze for SocketRuntimeProvider
impl RefUnwindSafe for SocketRuntimeProvider
impl Send for SocketRuntimeProvider
impl Sync for SocketRuntimeProvider
impl Unpin for SocketRuntimeProvider
impl UnsafeUnpin for SocketRuntimeProvider
impl UnwindSafe for SocketRuntimeProvider